Class: Aws::ConfigService::Types::AggregateComplianceByConfigRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Indicates whether an Config rule is compliant based on account ID, region, compliance, and rule name.

A rule is compliant if all of the resources that the rule evaluated comply with it. It is noncompliant if any of these resources do not comply.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The 12-digit account ID of the source account.



64
65
66
67
68
69
70
71
# File 'lib/aws-sdk-configservice/types.rb', line 64

class AggregateComplianceByConfigRule < Struct.new(
  :config_rule_name,
  :compliance,
  :account_id,
  :aws_region)
  SENSITIVE = []
  include Aws::Structure
end

#aws_regionString

The source region from where the data is aggregated.



64
65
66
67
68
69
70
71
# File 'lib/aws-sdk-configservice/types.rb', line 64

class AggregateComplianceByConfigRule < Struct.new(
  :config_rule_name,
  :compliance,
  :account_id,
  :aws_region)
  SENSITIVE = []
  include Aws::Structure
end

#complianceTypes::Compliance

Indicates whether an Amazon Web Services resource or Config rule is compliant and provides the number of contributors that affect the compliance.



64
65
66
67
68
69
70
71
# File 'lib/aws-sdk-configservice/types.rb', line 64

class AggregateComplianceByConfigRule < Struct.new(
  :config_rule_name,
  :compliance,
  :account_id,
  :aws_region)
  SENSITIVE = []
  include Aws::Structure
end

#config_rule_nameString

The name of the Config rule.



64
65
66
67
68
69
70
71
# File 'lib/aws-sdk-configservice/types.rb', line 64

class AggregateComplianceByConfigRule < Struct.new(
  :config_rule_name,
  :compliance,
  :account_id,
  :aws_region)
  SENSITIVE = []
  include Aws::Structure
end