Class: Aws::ConfigService::Types::ConfigExportDeliveryInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::ConfigExportDeliveryInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Provides status of the delivery of the snapshot or the configuration history to the specified Amazon S3 bucket. Also provides the status of notifications about the Amazon S3 delivery to the specified Amazon SNS topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_attempt_time ⇒ Time
The time of the last attempted delivery.
-
#last_error_code ⇒ String
The error code from the last attempted delivery.
-
#last_error_message ⇒ String
The error message from the last attempted delivery.
-
#last_status ⇒ String
Status of the last attempted delivery.
-
#last_successful_time ⇒ Time
The time of the last successful delivery.
-
#next_delivery_time ⇒ Time
The time that the next delivery occurs.
Instance Attribute Details
#last_attempt_time ⇒ Time
The time of the last attempted delivery.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |
#last_error_code ⇒ String
The error code from the last attempted delivery.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |
#last_error_message ⇒ String
The error message from the last attempted delivery.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |
#last_status ⇒ String
Status of the last attempted delivery.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |
#last_successful_time ⇒ Time
The time of the last successful delivery.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |
#next_delivery_time ⇒ Time
The time that the next delivery occurs.
969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-configservice/types.rb', line 969 class ConfigExportDeliveryInfo < Struct.new( :last_status, :last_error_code, :last_error_message, :last_attempt_time, :last_successful_time, :next_delivery_time) SENSITIVE = [] include Aws::Structure end |