Class: Aws::ConfigService::Types::ConflictException

Inherits:
EmptyStructure
  • Object
show all
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

For PutServiceLinkedConfigurationRecorder, you cannot create a service-linked recorder because a service-linked recorder already exists for the specified service.

For PutThirdPartyServiceLinkedConfigurationRecorder, you cannot create a service-linked recorder because the specified service principal does not support multiple configuration recorders and one already exists.

For PutThirdPartyServiceLinkedConfigurationRecorder, another in-progress operation is currently referencing the same connector or service principal. Please try again later.

For PutConnector, you cannot create a connector because a connector already exists for the specified connector configuration.

For DeleteServiceLinkedConfigurationRecorder, you cannot delete the service-linked recorder because it is currently in use by the linked Amazon Web Services service.

For DeleteServiceLinkedConfigurationRecorder, another in-progress operation is currently referencing the same connector. Please try again later.

For DeleteConnector, another in-progress operation is currently referencing the connector. Please try again later.

For DeleteDeliveryChannel, you cannot delete the specified delivery channel because the customer managed configuration recorder is running. Use the StopConfigurationRecorder operation to stop the customer managed configuration recorder.

For AssociateResourceTypes and DisassociateResourceTypes, one of the following errors:

  • For service-linked configuration recorders, the configuration recorder is not in use by the service. No association or dissociation of resource types is permitted.

  • For service-linked configuration recorders, your requested change to the configuration recorder has been denied by its linked Amazon Web Services service.