Class: Aws::ConfigService::Types::ConformancePackDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Returns details of a conformance pack. A conformance pack is a collection of Config rules and remediation actions that can be easily deployed in an account and a region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conformance_pack_arnString

Amazon Resource Name (ARN) of the conformance pack.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_idString

ID of the conformance pack.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_input_parametersArray<Types::ConformancePackInputParameter>

A list of ConformancePackInputParameter objects.



2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_nameString

Name of the conformance pack.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The Amazon Web Services service that created the conformance pack.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_s3_bucketString

The name of the Amazon S3 bucket where Config stores conformance pack templates.

This field is optional.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_s3_key_prefixString

The prefix for the Amazon S3 bucket.

This field is optional.

Returns:

  • (String)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_requested_timeTime

The last time a conformation pack update was requested.

Returns:

  • (Time)


2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#template_ssm_document_detailsTypes::TemplateSSMDocumentDetails

An object that contains the name or Amazon Resource Name (ARN) of the Amazon Web Services Systems Manager document (SSM document) and the version of the SSM document that is used to create a conformance pack.



2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-configservice/types.rb', line 2139

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end