Class: Aws::ConfigService::Types::ConformancePackEvaluationResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

The details of a conformance pack evaluation. Provides Config rule and Amazon Web Services resource type that was evaluated, the compliance of the conformance pack, related time stamps, and supplementary information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotationString

Supplementary information about how the evaluation determined the compliance.

Returns:

  • (String)


2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/aws-sdk-configservice/types.rb', line 2161

class ConformancePackEvaluationResult < Struct.new(
  :compliance_type,
  :evaluation_result_identifier,
  :config_rule_invoked_time,
  :result_recorded_time,
  :annotation)
  SENSITIVE = []
  include Aws::Structure
end

#compliance_typeString

The compliance type. The allowed values are ‘COMPLIANT` and `NON_COMPLIANT`. `INSUFFICIENT_DATA` is not supported.

Returns:

  • (String)


2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/aws-sdk-configservice/types.rb', line 2161

class ConformancePackEvaluationResult < Struct.new(
  :compliance_type,
  :evaluation_result_identifier,
  :config_rule_invoked_time,
  :result_recorded_time,
  :annotation)
  SENSITIVE = []
  include Aws::Structure
end

#config_rule_invoked_timeTime

The time when Config rule evaluated Amazon Web Services resource.

Returns:

  • (Time)


2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/aws-sdk-configservice/types.rb', line 2161

class ConformancePackEvaluationResult < Struct.new(
  :compliance_type,
  :evaluation_result_identifier,
  :config_rule_invoked_time,
  :result_recorded_time,
  :annotation)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_result_identifierTypes::EvaluationResultIdentifier

Uniquely identifies an evaluation result.



2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/aws-sdk-configservice/types.rb', line 2161

class ConformancePackEvaluationResult < Struct.new(
  :compliance_type,
  :evaluation_result_identifier,
  :config_rule_invoked_time,
  :result_recorded_time,
  :annotation)
  SENSITIVE = []
  include Aws::Structure
end

#result_recorded_timeTime

The time when Config recorded the evaluation result.

Returns:

  • (Time)


2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/aws-sdk-configservice/types.rb', line 2161

class ConformancePackEvaluationResult < Struct.new(
  :compliance_type,
  :evaluation_result_identifier,
  :config_rule_invoked_time,
  :result_recorded_time,
  :annotation)
  SENSITIVE = []
  include Aws::Structure
end