Class: Aws::ConfigService::Types::Connector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

The details of the connector, including the connector configuration and connector ARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the connector.

Returns:

  • (String)


2376
2377
2378
2379
2380
2381
2382
2383
# File 'lib/aws-sdk-configservice/types.rb', line 2376

class Connector < Struct.new(
  :name,
  :arn,
  :connector_configuration,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#connector_configurationTypes::ConnectorConfiguration

The provider-specific configuration for connecting to the third-party cloud service provider.



2376
2377
2378
2379
2380
2381
2382
2383
# File 'lib/aws-sdk-configservice/types.rb', line 2376

class Connector < Struct.new(
  :name,
  :arn,
  :connector_configuration,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The date and time that the connector was created.

Returns:

  • (Time)


2376
2377
2378
2379
2380
2381
2382
2383
# File 'lib/aws-sdk-configservice/types.rb', line 2376

class Connector < Struct.new(
  :name,
  :arn,
  :connector_configuration,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connector.

Returns:

  • (String)


2376
2377
2378
2379
2380
2381
2382
2383
# File 'lib/aws-sdk-configservice/types.rb', line 2376

class Connector < Struct.new(
  :name,
  :arn,
  :connector_configuration,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end