Class: Aws::ConfigService::Types::ConnectorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::ConnectorSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
A summary of a connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
-
#created_time ⇒ Time
The date and time that the connector was created.
-
#name ⇒ String
The name of the connector.
-
#provider ⇒ String
The third-party cloud service provider.
-
#tenant_identifier ⇒ String
The Azure tenant identifier for the connector.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/aws-sdk-configservice/types.rb', line 2446 class ConnectorSummary < Struct.new( :arn, :name, :provider, :tenant_identifier, :created_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The date and time that the connector was created.
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/aws-sdk-configservice/types.rb', line 2446 class ConnectorSummary < Struct.new( :arn, :name, :provider, :tenant_identifier, :created_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connector.
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/aws-sdk-configservice/types.rb', line 2446 class ConnectorSummary < Struct.new( :arn, :name, :provider, :tenant_identifier, :created_time) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The third-party cloud service provider. Currently, AZURE is
supported.
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/aws-sdk-configservice/types.rb', line 2446 class ConnectorSummary < Struct.new( :arn, :name, :provider, :tenant_identifier, :created_time) SENSITIVE = [] include Aws::Structure end |
#tenant_identifier ⇒ String
The Azure tenant identifier for the connector.
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/aws-sdk-configservice/types.rb', line 2446 class ConnectorSummary < Struct.new( :arn, :name, :provider, :tenant_identifier, :created_time) SENSITIVE = [] include Aws::Structure end |