Class: Aws::ConfigService::Types::CustomPolicyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::CustomPolicyDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Provides the runtime system, policy definition, and whether debug logging enabled. You can specify the following CustomPolicyDetails parameter values only for Config Custom Policy rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_debug_log_delivery ⇒ Boolean
The boolean expression for enabling debug logging for your Config Custom Policy rule.
-
#policy_runtime ⇒ String
The runtime system for your Config Custom Policy rule.
-
#policy_text ⇒ String
The policy definition containing the logic for your Config Custom Policy rule.
Instance Attribute Details
#enable_debug_log_delivery ⇒ Boolean
The boolean expression for enabling debug logging for your Config
Custom Policy rule. The default value is false.
2483 2484 2485 2486 2487 2488 2489 |
# File 'lib/aws-sdk-configservice/types.rb', line 2483 class CustomPolicyDetails < Struct.new( :policy_runtime, :policy_text, :enable_debug_log_delivery) SENSITIVE = [] include Aws::Structure end |
#policy_runtime ⇒ String
The runtime system for your Config Custom Policy rule. Guard is a policy-as-code language that allows you to write policies that are enforced by Config Custom Policy rules. For more information about Guard, see the Guard GitHub Repository.
2483 2484 2485 2486 2487 2488 2489 |
# File 'lib/aws-sdk-configservice/types.rb', line 2483 class CustomPolicyDetails < Struct.new( :policy_runtime, :policy_text, :enable_debug_log_delivery) SENSITIVE = [] include Aws::Structure end |
#policy_text ⇒ String
The policy definition containing the logic for your Config Custom Policy rule.
2483 2484 2485 2486 2487 2488 2489 |
# File 'lib/aws-sdk-configservice/types.rb', line 2483 class CustomPolicyDetails < Struct.new( :policy_runtime, :policy_text, :enable_debug_log_delivery) SENSITIVE = [] include Aws::Structure end |