Class: Aws::ConfigService::Types::DeleteOrganizationConfigRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DeleteOrganizationConfigRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organization_config_rule_name ⇒ String
The name of organization Config rule that you want to delete.
Instance Attribute Details
#organization_config_rule_name ⇒ String
The name of organization Config rule that you want to delete.
2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-configservice/types.rb', line 2444 class DeleteOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name) SENSITIVE = [] include Aws::Structure end |