Class: Aws::ConfigService::Types::DescribeAggregateComplianceByConfigRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeAggregateComplianceByConfigRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_aggregator_name ⇒ String
The name of the configuration aggregator.
-
#filters ⇒ Types::ConfigRuleComplianceFilters
Filters the results by ConfigRuleComplianceFilters object.
-
#limit ⇒ Integer
The maximum number of evaluation results returned on each page.
-
#next_token ⇒ String
The
nextTokenstring returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#configuration_aggregator_name ⇒ String
The name of the configuration aggregator.
2948 2949 2950 2951 2952 2953 2954 2955 |
# File 'lib/aws-sdk-configservice/types.rb', line 2948 class DescribeAggregateComplianceByConfigRulesRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::ConfigRuleComplianceFilters
Filters the results by ConfigRuleComplianceFilters object.
2948 2949 2950 2951 2952 2953 2954 2955 |
# File 'lib/aws-sdk-configservice/types.rb', line 2948 class DescribeAggregateComplianceByConfigRulesRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of evaluation results returned on each page. The default is maximum. If you specify 0, Config uses the default.
2948 2949 2950 2951 2952 2953 2954 2955 |
# File 'lib/aws-sdk-configservice/types.rb', line 2948 class DescribeAggregateComplianceByConfigRulesRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned on a previous page that you use to
get the next page of results in a paginated response.
2948 2949 2950 2951 2952 2953 2954 2955 |
# File 'lib/aws-sdk-configservice/types.rb', line 2948 class DescribeAggregateComplianceByConfigRulesRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |