Class: Aws::ConfigService::Types::DescribeAggregationAuthorizationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_authorizationsArray<Types::AggregationAuthorization>

Returns a list of authorizations granted to various aggregator accounts and regions.



3056
3057
3058
3059
3060
3061
# File 'lib/aws-sdk-configservice/types.rb', line 3056

class DescribeAggregationAuthorizationsResponse < Struct.new(
  :aggregation_authorizations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Returns:

  • (String)


3056
3057
3058
3059
3060
3061
# File 'lib/aws-sdk-configservice/types.rb', line 3056

class DescribeAggregationAuthorizationsResponse < Struct.new(
  :aggregation_authorizations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end