Class: Aws::ConfigService::Types::DescribeConfigRuleEvaluationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConfigRuleEvaluationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_rule_names ⇒ Array<String>
The name of the Config managed rules for which you want status information.
-
#limit ⇒ Integer
The number of rule evaluation results that you want returned.
-
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#config_rule_names ⇒ Array<String>
The name of the Config managed rules for which you want status information. If you do not specify any names, Config returns status information for all Config managed rules that you use.
3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-configservice/types.rb', line 3005 class DescribeConfigRuleEvaluationStatusRequest < Struct.new( :config_rule_names, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The number of rule evaluation results that you want returned.
This parameter is required if the rule limit for your account is more than the default of 1000 rules.
For information about requesting a rule limit increase, see [Config Limits] in the *Amazon Web Services General Reference Guide*.
[1]: docs.aws.amazon.com/general/latest/gr/aws_service_limits.html#limits_config
3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-configservice/types.rb', line 3005 class DescribeConfigRuleEvaluationStatusRequest < Struct.new( :config_rule_names, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-configservice/types.rb', line 3005 class DescribeConfigRuleEvaluationStatusRequest < Struct.new( :config_rule_names, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |