Class: Aws::ConfigService::Types::DescribeConfigRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConfigRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_rule_names ⇒ Array<String>
The names of the Config rules for which you want details.
-
#filters ⇒ Types::DescribeConfigRulesFilters
Returns a list of Detective or Proactive Config rules.
-
#next_token ⇒ String
The
nextTokenstring returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#config_rule_names ⇒ Array<String>
The names of the Config rules for which you want details. If you do not specify any names, Config returns details for all your rules.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-configservice/types.rb', line 3267 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :filters, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::DescribeConfigRulesFilters
Returns a list of Detective or Proactive Config rules. By default, this API returns an unfiltered list. For more information on Detective or Proactive Config rules, see Evaluation Mode in the Config Developer Guide.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-configservice/types.rb', line 3267 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :filters, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned on a previous page that you use to
get the next page of results in a paginated response.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-configservice/types.rb', line 3267 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :filters, :next_token) SENSITIVE = [] include Aws::Structure end |