Class: Aws::ConfigService::Types::DescribeConfigurationAggregatorSourcesStatusResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConfigurationAggregatorSourcesStatusResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregated_source_status_list ⇒ Array<Types::AggregatedSourceStatus>
Returns an AggregatedSourceStatus object.
-
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#aggregated_source_status_list ⇒ Array<Types::AggregatedSourceStatus>
Returns an AggregatedSourceStatus object.
3153 3154 3155 3156 3157 3158 |
# File 'lib/aws-sdk-configservice/types.rb', line 3153 class DescribeConfigurationAggregatorSourcesStatusResponse < Struct.new( :aggregated_source_status_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
3153 3154 3155 3156 3157 3158 |
# File 'lib/aws-sdk-configservice/types.rb', line 3153 class DescribeConfigurationAggregatorSourcesStatusResponse < Struct.new( :aggregated_source_status_list, :next_token) SENSITIVE = [] include Aws::Structure end |