Method: Aws::ConfigService::Types::DescribeConfigurationAggregatorsResponse#next_token

Defined in:
lib/aws-sdk-configservice/types.rb

#next_tokenString

The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Returns:

  • (String)


3183
3184
3185
3186
3187
3188
# File 'lib/aws-sdk-configservice/types.rb', line 3183

class DescribeConfigurationAggregatorsResponse < Struct.new(
  :configuration_aggregators,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end