Class: Aws::ConfigService::Types::DescribeConformancePacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConformancePacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conformance_pack_names ⇒ Array<String>
Comma-separated list of conformance pack names for which you want details.
-
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
-
#next_token ⇒ String
The
nextTokenstring returned in a previous request that you use to request the next page of results in a paginated response.
Instance Attribute Details
#conformance_pack_names ⇒ Array<String>
Comma-separated list of conformance pack names for which you want details. If you do not specify any names, Config returns details for all your conformance packs.
3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-configservice/types.rb', line 3601 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-configservice/types.rb', line 3601 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned in a previous request that you use
to request the next page of results in a paginated response.
3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-configservice/types.rb', line 3601 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |