Class: Aws::ConfigService::Types::DescribeOrganizationConfigRuleStatusesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeOrganizationConfigRuleStatusesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of ‘OrganizationConfigRuleStatuses` returned on each page.
-
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
-
#organization_config_rule_names ⇒ Array<String>
The names of organization Config rules for which you want status details.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of ‘OrganizationConfigRuleStatuses` returned on each page. If you do no specify a number, Config uses the default. The default is 100.
3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-configservice/types.rb', line 3513 class DescribeOrganizationConfigRuleStatusesRequest < Struct.new( :organization_config_rule_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-configservice/types.rb', line 3513 class DescribeOrganizationConfigRuleStatusesRequest < Struct.new( :organization_config_rule_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#organization_config_rule_names ⇒ Array<String>
The names of organization Config rules for which you want status details. If you do not specify any names, Config returns details for all your organization Config rules.
3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-configservice/types.rb', line 3513 class DescribeOrganizationConfigRuleStatusesRequest < Struct.new( :organization_config_rule_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |