Class: Aws::ConfigService::Types::DescribeOrganizationConformancePackStatusesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeOrganizationConformancePackStatusesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of OrganizationConformancePackStatuses returned on each page.
-
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
-
#organization_conformance_pack_names ⇒ Array<String>
The names of organization conformance packs for which you want status details.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of OrganizationConformancePackStatuses returned on each page. If you do no specify a number, Config uses the default. The default is 100.
3793 3794 3795 3796 3797 3798 3799 |
# File 'lib/aws-sdk-configservice/types.rb', line 3793 class DescribeOrganizationConformancePackStatusesRequest < Struct.new( :organization_conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
3793 3794 3795 3796 3797 3798 3799 |
# File 'lib/aws-sdk-configservice/types.rb', line 3793 class DescribeOrganizationConformancePackStatusesRequest < Struct.new( :organization_conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#organization_conformance_pack_names ⇒ Array<String>
The names of organization conformance packs for which you want status details. If you do not specify any names, Config returns details for all your organization conformance packs.
3793 3794 3795 3796 3797 3798 3799 |
# File 'lib/aws-sdk-configservice/types.rb', line 3793 class DescribeOrganizationConformancePackStatusesRequest < Struct.new( :organization_conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |