Class: Aws::ConfigService::Types::DisassociateResourceTypesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_recorder_arnString

The Amazon Resource Name (ARN) of the specified configuration recorder.

Returns:

  • (String)


4079
4080
4081
4082
4083
4084
# File 'lib/aws-sdk-configservice/types.rb', line 4079

class DisassociateResourceTypesRequest < Struct.new(
  :configuration_recorder_arn,
  :resource_types)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typesArray<String>

The list of resource types you want to remove from the recording group of the specified configuration recorder.

Returns:

  • (Array<String>)


4079
4080
4081
4082
4083
4084
# File 'lib/aws-sdk-configservice/types.rb', line 4079

class DisassociateResourceTypesRequest < Struct.new(
  :configuration_recorder_arn,
  :resource_types)
  SENSITIVE = []
  include Aws::Structure
end