Class: Aws::ConfigService::Types::DisassociateResourceTypesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_recorderTypes::ConfigurationRecorder

Records configuration changes to the resource types in scope.

For more information about the configuration recorder, see Working with the Configuration Recorder in the Config Developer Guide.



4100
4101
4102
4103
4104
# File 'lib/aws-sdk-configservice/types.rb', line 4100

class DisassociateResourceTypesResponse < Struct.new(
  :configuration_recorder)
  SENSITIVE = []
  include Aws::Structure
end