Class: Aws::ConfigService::Types::EvaluationResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

The details of an Config evaluation. Provides the Amazon Web Services resource that was evaluated, the compliance of the resource, related time stamps, and supplementary information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotationString

Supplementary information about how the evaluation determined the compliance.

Returns:

  • (String)


4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end

#compliance_typeString

Indicates whether the Amazon Web Services resource complies with the Config rule that evaluated it.

For the ‘EvaluationResult` data type, Config supports only the `COMPLIANT`, `NON_COMPLIANT`, and `NOT_APPLICABLE` values. Config does not support the `INSUFFICIENT_DATA` value for the `EvaluationResult` data type.

Returns:

  • (String)


4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end

#config_rule_invoked_timeTime

The time when the Config rule evaluated the Amazon Web Services resource.

Returns:

  • (Time)


4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_result_identifierTypes::EvaluationResultIdentifier

Uniquely identifies the evaluation result.



4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end

#result_recorded_timeTime

The time when Config recorded the evaluation result.

Returns:

  • (Time)


4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end

#result_tokenString

An encrypted token that associates an evaluation with an Config rule. The token identifies the rule, the Amazon Web Services resource being evaluated, and the event that triggered the evaluation.

Returns:

  • (String)


4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-configservice/types.rb', line 4040

class EvaluationResult < Struct.new(
  :evaluation_result_identifier,
  :compliance_type,
  :result_recorded_time,
  :config_rule_invoked_time,
  :annotation,
  :result_token)
  SENSITIVE = []
  include Aws::Structure
end