Class: Aws::ConfigService::Types::GetComplianceSummaryByResourceTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compliance_summaries_by_resource_typeArray<Types::ComplianceSummaryByResourceType>

The number of resources that are compliant and the number that are noncompliant. If one or more resource types were provided with the request, the numbers are returned for each resource type. The maximum number returned is 100.



4761
4762
4763
4764
4765
# File 'lib/aws-sdk-configservice/types.rb', line 4761

class GetComplianceSummaryByResourceTypeResponse < Struct.new(
  :compliance_summaries_by_resource_type)
  SENSITIVE = []
  include Aws::Structure
end