Class: Aws::ConfigService::Types::GetConformancePackComplianceDetailsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GetConformancePackComplianceDetailsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conformance_pack_name ⇒ String
Name of the conformance pack.
-
#conformance_pack_rule_evaluation_results ⇒ Array<Types::ConformancePackEvaluationResult>
Returns a list of
ConformancePackEvaluationResultobjects. -
#next_token ⇒ String
The
nextTokenstring returned in a previous request that you use to request the next page of results in a paginated response.
Instance Attribute Details
#conformance_pack_name ⇒ String
Name of the conformance pack.
5002 5003 5004 5005 5006 5007 5008 |
# File 'lib/aws-sdk-configservice/types.rb', line 5002 class GetConformancePackComplianceDetailsResponse < Struct.new( :conformance_pack_name, :conformance_pack_rule_evaluation_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#conformance_pack_rule_evaluation_results ⇒ Array<Types::ConformancePackEvaluationResult>
Returns a list of ConformancePackEvaluationResult objects.
5002 5003 5004 5005 5006 5007 5008 |
# File 'lib/aws-sdk-configservice/types.rb', line 5002 class GetConformancePackComplianceDetailsResponse < Struct.new( :conformance_pack_name, :conformance_pack_rule_evaluation_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned in a previous request that you use
to request the next page of results in a paginated response.
5002 5003 5004 5005 5006 5007 5008 |
# File 'lib/aws-sdk-configservice/types.rb', line 5002 class GetConformancePackComplianceDetailsResponse < Struct.new( :conformance_pack_name, :conformance_pack_rule_evaluation_results, :next_token) SENSITIVE = [] include Aws::Structure end |