Class: Aws::ConfigService::Types::GetConformancePackComplianceSummaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GetConformancePackComplianceSummaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conformance_pack_names ⇒ Array<String>
Names of conformance packs.
-
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
-
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#conformance_pack_names ⇒ Array<String>
Names of conformance packs.
5025 5026 5027 5028 5029 5030 5031 |
# File 'lib/aws-sdk-configservice/types.rb', line 5025 class GetConformancePackComplianceSummaryRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
5025 5026 5027 5028 5029 5030 5031 |
# File 'lib/aws-sdk-configservice/types.rb', line 5025 class GetConformancePackComplianceSummaryRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
5025 5026 5027 5028 5029 5030 5031 |
# File 'lib/aws-sdk-configservice/types.rb', line 5025 class GetConformancePackComplianceSummaryRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |