Class: Aws::ConfigService::Types::GetOrganizationConformancePackDetailedStatusResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GetOrganizationConformancePackDetailedStatusResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
-
#organization_conformance_pack_detailed_statuses ⇒ Array<Types::OrganizationConformancePackDetailedStatus>
A list of
OrganizationConformancePackDetailedStatusobjects.
Instance Attribute Details
#next_token ⇒ String
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.
5268 5269 5270 5271 5272 5273 |
# File 'lib/aws-sdk-configservice/types.rb', line 5268 class GetOrganizationConformancePackDetailedStatusResponse < Struct.new( :organization_conformance_pack_detailed_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#organization_conformance_pack_detailed_statuses ⇒ Array<Types::OrganizationConformancePackDetailedStatus>
A list of OrganizationConformancePackDetailedStatus objects.
5268 5269 5270 5271 5272 5273 |
# File 'lib/aws-sdk-configservice/types.rb', line 5268 class GetOrganizationConformancePackDetailedStatusResponse < Struct.new( :organization_conformance_pack_detailed_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |