Class: Aws::ConfigService::Types::GetResourceConfigHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

The input for the GetResourceConfigHistory action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#chronological_orderString

The chronological order for configuration items listed. By default, the results are listed in reverse chronological order.

Returns:

  • (String)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#earlier_timeTime

The chronologically earliest time in the time range for which the history requested. If not specified, the action returns paginated results that contain configuration items that start when the first configuration item was recorded.

Returns:

  • (Time)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#later_timeTime

The chronologically latest time in the time range for which the history requested. If not specified, current time is taken.

Returns:

  • (Time)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of configuration items returned on each page. The default is 10. You cannot specify a number greater than 100. If you specify 0, Config uses the default.

Returns:

  • (Integer)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.

Returns:

  • (String)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the resource (for example., sg-xxxxxx).

Returns:

  • (String)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type.

Returns:

  • (String)


5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
# File 'lib/aws-sdk-configservice/types.rb', line 5340

class GetResourceConfigHistoryRequest < Struct.new(
  :resource_type,
  :resource_id,
  :later_time,
  :earlier_time,
  :chronological_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end