Class: Aws::ConfigService::Types::GetResourceEvaluationSummaryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GetResourceEvaluationSummaryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compliance ⇒ String
The compliance status of the resource evaluation summary.
-
#evaluation_context ⇒ Types::EvaluationContext
Returns an ‘EvaluationContext` object.
-
#evaluation_mode ⇒ String
Lists results of the mode that you requested to retrieve the resource evaluation summary.
-
#evaluation_start_timestamp ⇒ Time
The start timestamp when Config rule starts evaluating compliance for the provided resource details.
-
#evaluation_status ⇒ Types::EvaluationStatus
Returns an ‘EvaluationStatus` object.
-
#resource_details ⇒ Types::ResourceDetails
Returns a ‘ResourceDetails` object.
-
#resource_evaluation_id ⇒ String
The unique ‘ResourceEvaluationId` of Amazon Web Services resource execution for which you want to retrieve the evaluation summary.
Instance Attribute Details
#compliance ⇒ String
The compliance status of the resource evaluation summary.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#evaluation_context ⇒ Types::EvaluationContext
Returns an ‘EvaluationContext` object.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#evaluation_mode ⇒ String
Lists results of the mode that you requested to retrieve the resource evaluation summary. The valid values are Detective or Proactive.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#evaluation_start_timestamp ⇒ Time
The start timestamp when Config rule starts evaluating compliance for the provided resource details.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#evaluation_status ⇒ Types::EvaluationStatus
Returns an ‘EvaluationStatus` object.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#resource_details ⇒ Types::ResourceDetails
Returns a ‘ResourceDetails` object.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |
#resource_evaluation_id ⇒ String
The unique ‘ResourceEvaluationId` of Amazon Web Services resource execution for which you want to retrieve the evaluation summary.
5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 |
# File 'lib/aws-sdk-configservice/types.rb', line 5206 class GetResourceEvaluationSummaryResponse < Struct.new( :resource_evaluation_id, :evaluation_mode, :evaluation_status, :evaluation_start_timestamp, :compliance, :evaluation_context, :resource_details) SENSITIVE = [] include Aws::Structure end |