Class: Aws::ConfigService::Types::GroupedResourceCount
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GroupedResourceCount
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
The count of resources that are grouped by the group name.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the group that can be region, account ID, or resource type.
-
#resource_count ⇒ Integer
The number of resources in the group.
Instance Attribute Details
#group_name ⇒ String
The name of the group that can be region, account ID, or resource
type. For example, region1, region2 if the region was chosen as
GroupByKey.
5470 5471 5472 5473 5474 5475 |
# File 'lib/aws-sdk-configservice/types.rb', line 5470 class GroupedResourceCount < Struct.new( :group_name, :resource_count) SENSITIVE = [] include Aws::Structure end |
#resource_count ⇒ Integer
The number of resources in the group.
5470 5471 5472 5473 5474 5475 |
# File 'lib/aws-sdk-configservice/types.rb', line 5470 class GroupedResourceCount < Struct.new( :group_name, :resource_count) SENSITIVE = [] include Aws::Structure end |