Class: Aws::ConfigService::Types::LimitExceededException
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::ConfigService::Types::LimitExceededException
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
For StartConfigRulesEvaluation API, this exception is thrown if an evaluation is in progress or if you call the StartConfigRulesEvaluation API more than once per minute.
For PutConfigurationAggregator API, this exception is thrown if the number of accounts and aggregators exceeds the limit.