Class: Aws::ConfigService::Types::ListResourceEvaluationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::ListResourceEvaluationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenstring returned on a previous page that you use to get the next page of results in a paginated response. -
#resource_evaluations ⇒ Array<Types::ResourceEvaluation>
Returns a
ResourceEvaluationsobject.
Instance Attribute Details
#next_token ⇒ String
The nextToken string returned on a previous page that you use to
get the next page of results in a paginated response.
5982 5983 5984 5985 5986 5987 |
# File 'lib/aws-sdk-configservice/types.rb', line 5982 class ListResourceEvaluationsResponse < Struct.new( :resource_evaluations, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_evaluations ⇒ Array<Types::ResourceEvaluation>
Returns a ResourceEvaluations object.
5982 5983 5984 5985 5986 5987 |
# File 'lib/aws-sdk-configservice/types.rb', line 5982 class ListResourceEvaluationsResponse < Struct.new( :resource_evaluations, :next_token) SENSITIVE = [] include Aws::Structure end |