Class: Aws::ConfigService::Types::MaxNumberOfOrganizationConformancePacksExceededException
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::ConfigService::Types::MaxNumberOfOrganizationConformancePacksExceededException
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
You have reached the limit of the number of organization conformance packs you can create in an account. For more information, see Service Limits in the Config Developer Guide.