Class: Aws::ConfigService::Types::OrganizationConfigRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::OrganizationConfigRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
An organization Config rule that has information about Config rules that Config creates in member accounts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#excluded_accounts ⇒ Array<String>
A comma-separated list of accounts excluded from organization Config rule.
-
#last_update_time ⇒ Time
The timestamp of the last update.
-
#organization_config_rule_arn ⇒ String
Amazon Resource Name (ARN) of organization Config rule.
-
#organization_config_rule_name ⇒ String
The name that you assign to organization Config rule.
-
#organization_custom_policy_rule_metadata ⇒ Types::OrganizationCustomPolicyRuleMetadataNoPolicy
An object that specifies metadata for your organization's Config Custom Policy rule.
-
#organization_custom_rule_metadata ⇒ Types::OrganizationCustomRuleMetadata
An
OrganizationCustomRuleMetadataobject. -
#organization_managed_rule_metadata ⇒ Types::OrganizationManagedRuleMetadata
An
OrganizationManagedRuleMetadataobject.
Instance Attribute Details
#excluded_accounts ⇒ Array<String>
A comma-separated list of accounts excluded from organization Config rule.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#last_update_time ⇒ Time
The timestamp of the last update.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#organization_config_rule_arn ⇒ String
Amazon Resource Name (ARN) of organization Config rule.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#organization_config_rule_name ⇒ String
The name that you assign to organization Config rule.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#organization_custom_policy_rule_metadata ⇒ Types::OrganizationCustomPolicyRuleMetadataNoPolicy
An object that specifies metadata for your organization's Config Custom Policy rule. The metadata includes the runtime system in use, which accounts have debug logging enabled, and other custom rule metadata, such as resource type, resource ID of Amazon Web Services resource, and organization trigger types that initiate Config to evaluate Amazon Web Services resources against a rule.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#organization_custom_rule_metadata ⇒ Types::OrganizationCustomRuleMetadata
An OrganizationCustomRuleMetadata object.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |
#organization_managed_rule_metadata ⇒ Types::OrganizationManagedRuleMetadata
An OrganizationManagedRuleMetadata object.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/aws-sdk-configservice/types.rb', line 6467 class OrganizationConfigRule < Struct.new( :organization_config_rule_name, :organization_config_rule_arn, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :last_update_time, :organization_custom_policy_rule_metadata) SENSITIVE = [] include Aws::Structure end |