Class: Aws::ConfigService::Types::OrganizationConformancePackDetailedStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::OrganizationConformancePackDetailedStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Organization conformance pack creation or deletion status in each member account. This includes the name of the conformance pack, the status, error code and error message when the conformance pack creation or deletion failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The 12-digit account ID of a member account.
-
#conformance_pack_name ⇒ String
The name of conformance pack deployed in the member account.
-
#error_code ⇒ String
An error code that is returned when conformance pack creation or deletion failed in the member account.
-
#error_message ⇒ String
An error message indicating that conformance pack account creation or deletion has failed due to an error in the member account.
-
#last_update_time ⇒ Time
The timestamp of the last status update.
-
#status ⇒ String
Indicates deployment status for conformance pack in a member account.
Instance Attribute Details
#account_id ⇒ String
The 12-digit account ID of a member account.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#conformance_pack_name ⇒ String
The name of conformance pack deployed in the member account.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
An error code that is returned when conformance pack creation or deletion failed in the member account.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message indicating that conformance pack account creation or deletion has failed due to an error in the member account.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#last_update_time ⇒ Time
The timestamp of the last status update.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates deployment status for conformance pack in a member account. When management account calls PutOrganizationConformancePack action for the first time, conformance pack status is created in the member account. When management account calls PutOrganizationConformancePack action for the second time, conformance pack status is updated in the member account. Conformance pack status is deleted when the management account deletes OrganizationConformancePack and disables service access for config-multiaccountsetup.amazonaws.com.
Config sets the state of the conformance pack to:
-
CREATE_SUCCESSFULwhen conformance pack has been created in the member account. -
CREATE_IN_PROGRESSwhen conformance pack is being created in the member account. -
CREATE_FAILEDwhen conformance pack creation has failed in the member account. -
DELETE_FAILEDwhen conformance pack deletion has failed in the member account. -
DELETE_IN_PROGRESSwhen conformance pack is being deleted in the member account. -
DELETE_SUCCESSFULwhen conformance pack has been deleted in the member account. -
UPDATE_SUCCESSFULwhen conformance pack has been updated in the member account. -
UPDATE_IN_PROGRESSwhen conformance pack is being updated in the member account. -
UPDATE_FAILEDwhen conformance pack deletion has failed in the member account.
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/aws-sdk-configservice/types.rb', line 5906 class OrganizationConformancePackDetailedStatus < Struct.new( :account_id, :conformance_pack_name, :status, :error_code, :error_message, :last_update_time) SENSITIVE = [] include Aws::Structure end |