Class: Aws::ConfigService::Types::PutOrganizationConfigRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::PutOrganizationConfigRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#excluded_accounts ⇒ Array<String>
A comma-separated list of accounts that you want to exclude from an organization Config rule.
-
#organization_config_rule_name ⇒ String
The name that you assign to an organization Config rule.
-
#organization_custom_policy_rule_metadata ⇒ Types::OrganizationCustomPolicyRuleMetadata
An
OrganizationCustomPolicyRuleMetadataobject. -
#organization_custom_rule_metadata ⇒ Types::OrganizationCustomRuleMetadata
An
OrganizationCustomRuleMetadataobject. -
#organization_managed_rule_metadata ⇒ Types::OrganizationManagedRuleMetadata
An
OrganizationManagedRuleMetadataobject. -
#tags ⇒ Array<Types::Tag>
The tags for the organization Config rule.
Instance Attribute Details
#excluded_accounts ⇒ Array<String>
A comma-separated list of accounts that you want to exclude from an organization Config rule.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#organization_config_rule_name ⇒ String
The name that you assign to an organization Config rule.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#organization_custom_policy_rule_metadata ⇒ Types::OrganizationCustomPolicyRuleMetadata
An OrganizationCustomPolicyRuleMetadata object. This object
specifies metadata for your organization's Config Custom Policy
rule. The metadata includes the runtime system in use, which
accounts have debug logging enabled, and other custom rule metadata,
such as resource type, resource ID of Amazon Web Services resource,
and organization trigger types that initiate Config to evaluate
Amazon Web Services resources against a rule.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#organization_custom_rule_metadata ⇒ Types::OrganizationCustomRuleMetadata
An OrganizationCustomRuleMetadata object. This object specifies
organization custom rule metadata such as resource type, resource ID
of Amazon Web Services resource, Lambda function ARN, and
organization trigger types that trigger Config to evaluate your
Amazon Web Services resources against a rule. It also provides the
frequency with which you want Config to run evaluations for the rule
if the trigger type is periodic.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#organization_managed_rule_metadata ⇒ Types::OrganizationManagedRuleMetadata
An OrganizationManagedRuleMetadata object. This object specifies
organization managed rule metadata such as resource type and ID of
Amazon Web Services resource along with the rule identifier. It also
provides the frequency with which you want Config to run evaluations
for the rule if the trigger type is periodic.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags for the organization Config rule. Each tag consists of a key and an optional value, both of which you define.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/aws-sdk-configservice/types.rb', line 7568 class PutOrganizationConfigRuleRequest < Struct.new( :organization_config_rule_name, :organization_managed_rule_metadata, :organization_custom_rule_metadata, :excluded_accounts, :organization_custom_policy_rule_metadata, :tags) SENSITIVE = [] include Aws::Structure end |