Class: Aws::ConfigService::Types::PutRemediationExceptionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::PutRemediationExceptionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_batches ⇒ Array<Types::FailedRemediationExceptionBatch>
Returns a list of failed remediation exceptions batch objects.
Instance Attribute Details
#failed_batches ⇒ Array<Types::FailedRemediationExceptionBatch>
Returns a list of failed remediation exceptions batch objects. Each object in the batch consists of a list of failed items and failure messages.
7425 7426 7427 7428 7429 |
# File 'lib/aws-sdk-configservice/types.rb', line 7425 class PutRemediationExceptionsResponse < Struct.new( :failed_batches) SENSITIVE = [] include Aws::Structure end |