Class: Aws::ConfigService::Types::RemediationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

An object that represents the details about the remediation exception. The details include the rule name, an explanation of an exception, the time when the exception will be deleted, the resource ID, and resource type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#config_rule_nameString

The name of the Config rule.

Returns:

  • (String)


8271
8272
8273
8274
8275
8276
8277
8278
8279
# File 'lib/aws-sdk-configservice/types.rb', line 8271

class RemediationException < Struct.new(
  :config_rule_name,
  :resource_type,
  :resource_id,
  :message,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The time when the remediation exception will be deleted.

Returns:

  • (Time)


8271
8272
8273
8274
8275
8276
8277
8278
8279
# File 'lib/aws-sdk-configservice/types.rb', line 8271

class RemediationException < Struct.new(
  :config_rule_name,
  :resource_type,
  :resource_id,
  :message,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

An explanation of an remediation exception.

Returns:

  • (String)


8271
8272
8273
8274
8275
8276
8277
8278
8279
# File 'lib/aws-sdk-configservice/types.rb', line 8271

class RemediationException < Struct.new(
  :config_rule_name,
  :resource_type,
  :resource_id,
  :message,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the resource (for example., sg-xxxxxx).

Returns:

  • (String)


8271
8272
8273
8274
8275
8276
8277
8278
8279
# File 'lib/aws-sdk-configservice/types.rb', line 8271

class RemediationException < Struct.new(
  :config_rule_name,
  :resource_type,
  :resource_id,
  :message,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of a resource.

Returns:

  • (String)


8271
8272
8273
8274
8275
8276
8277
8278
8279
# File 'lib/aws-sdk-configservice/types.rb', line 8271

class RemediationException < Struct.new(
  :config_rule_name,
  :resource_type,
  :resource_id,
  :message,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end