Class: Aws::ConfigService::Types::ResourceDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Returns information about the resource being evaluated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_configurationString

The resource definition to be evaluated as per the resource configuration schema type.

Returns:

  • (String)


8857
8858
8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-configservice/types.rb', line 8857

class ResourceDetails < Struct.new(
  :resource_id,
  :resource_type,
  :resource_configuration,
  :resource_configuration_schema_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_schema_typeString

The schema type of the resource configuration.

You can find the Resource type schema, or CFN_RESOURCE_SCHEMA, in "Amazon Web Services public extensions" within the CloudFormation registry or with the following CLI commmand: aws cloudformation describe-type --type-name "AWS::S3::Bucket" --type RESOURCE.

For more information, see Managing extensions through the CloudFormation registry and Amazon Web Services resource and property types reference in the CloudFormation User Guide.

Returns:

  • (String)


8857
8858
8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-configservice/types.rb', line 8857

class ResourceDetails < Struct.new(
  :resource_id,
  :resource_type,
  :resource_configuration,
  :resource_configuration_schema_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

A unique resource ID for an evaluation.

Returns:

  • (String)


8857
8858
8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-configservice/types.rb', line 8857

class ResourceDetails < Struct.new(
  :resource_id,
  :resource_type,
  :resource_configuration,
  :resource_configuration_schema_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource being evaluated.

Returns:

  • (String)


8857
8858
8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-configservice/types.rb', line 8857

class ResourceDetails < Struct.new(
  :resource_id,
  :resource_type,
  :resource_configuration,
  :resource_configuration_schema_type)
  SENSITIVE = []
  include Aws::Structure
end