Class: Aws::ConfigService::Types::Scope
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::Scope
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Defines which resources trigger an evaluation for an Config rule. The scope can include one or more resource types, a combination of a tag key and value, or a combination of one resource type and one resource ID. Specify a scope to constrain which resources trigger an evaluation for a rule. Otherwise, evaluations for the rule are triggered when any resource in your recording group changes in configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compliance_resource_id ⇒ String
The ID of the only Amazon Web Services resource that you want to trigger an evaluation for the rule.
-
#compliance_resource_types ⇒ Array<String>
The resource types of only those Amazon Web Services resources that you want to trigger an evaluation for the rule.
-
#service_principals ⇒ Array<String>
The service principals of the Amazon Web Services services for the rule.
-
#tag_key ⇒ String
The tag key that is applied to only those Amazon Web Services resources that you want to trigger an evaluation for the rule.
-
#tag_value ⇒ String
The tag value applied to only those Amazon Web Services resources that you want to trigger an evaluation for the rule.
Instance Attribute Details
#compliance_resource_id ⇒ String
The ID of the only Amazon Web Services resource that you want to trigger an evaluation for the rule. If you specify a resource ID, you must specify one resource type for ‘ComplianceResourceTypes`.
8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/aws-sdk-configservice/types.rb', line 8764 class Scope < Struct.new( :compliance_resource_types, :tag_key, :tag_value, :compliance_resource_id, :service_principals) SENSITIVE = [] include Aws::Structure end |
#compliance_resource_types ⇒ Array<String>
The resource types of only those Amazon Web Services resources that you want to trigger an evaluation for the rule. You can only specify one type if you also specify a resource ID for ‘ComplianceResourceId`.
8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/aws-sdk-configservice/types.rb', line 8764 class Scope < Struct.new( :compliance_resource_types, :tag_key, :tag_value, :compliance_resource_id, :service_principals) SENSITIVE = [] include Aws::Structure end |
#service_principals ⇒ Array<String>
The service principals of the Amazon Web Services services for the rule.
<note markdown=“1”> The field is populated only if the service-linked rule is created by a service. The field is empty if you create your own rule.
</note>
8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/aws-sdk-configservice/types.rb', line 8764 class Scope < Struct.new( :compliance_resource_types, :tag_key, :tag_value, :compliance_resource_id, :service_principals) SENSITIVE = [] include Aws::Structure end |
#tag_key ⇒ String
The tag key that is applied to only those Amazon Web Services resources that you want to trigger an evaluation for the rule.
8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/aws-sdk-configservice/types.rb', line 8764 class Scope < Struct.new( :compliance_resource_types, :tag_key, :tag_value, :compliance_resource_id, :service_principals) SENSITIVE = [] include Aws::Structure end |
#tag_value ⇒ String
The tag value applied to only those Amazon Web Services resources that you want to trigger an evaluation for the rule. If you specify a value for ‘TagValue`, you must also specify a value for `TagKey`.
8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/aws-sdk-configservice/types.rb', line 8764 class Scope < Struct.new( :compliance_resource_types, :tag_key, :tag_value, :compliance_resource_id, :service_principals) SENSITIVE = [] include Aws::Structure end |