Class: Aws::ConfigService::Types::StopConfigurationRecorderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::StopConfigurationRecorderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
The input for the StopConfigurationRecorder operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_recorder_name ⇒ String
The name of the customer managed configuration recorder that you want to stop.
Instance Attribute Details
#configuration_recorder_name ⇒ String
The name of the customer managed configuration recorder that you want to stop.
9230 9231 9232 9233 9234 |
# File 'lib/aws-sdk-configservice/types.rb', line 9230 class StopConfigurationRecorderRequest < Struct.new( :configuration_recorder_name) SENSITIVE = [] include Aws::Structure end |