Class: Aws::ConfigService::Types::ConformancePackDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

Returns details of a conformance pack. A conformance pack is a collection of Config rules and remediation actions that can be easily deployed in an account and a region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conformance_pack_arnString

Amazon Resource Name (ARN) of the conformance pack.

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_idString

ID of the conformance pack.

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_input_parametersArray<Types::ConformancePackInputParameter>

A list of ‘ConformancePackInputParameter` objects.



2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#conformance_pack_nameString

Name of the conformance pack.

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The Amazon Web Services service that created the conformance pack.

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_s3_bucketString

The name of the Amazon S3 bucket where Config stores conformance pack templates.

<note markdown=“1”> This field is optional.

</note>

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_s3_key_prefixString

The prefix for the Amazon S3 bucket.

<note markdown=“1”> This field is optional.

</note>

Returns:

  • (String)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_requested_timeTime

The last time a conformation pack update was requested.

Returns:

  • (Time)


2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end

#template_ssm_document_detailsTypes::TemplateSSMDocumentDetails

An object that contains the name or Amazon Resource Name (ARN) of the Amazon Web Services Systems Manager document (SSM document) and the version of the SSM document that is used to create a conformance pack.



2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-configservice/types.rb', line 2079

class ConformancePackDetail < Struct.new(
  :conformance_pack_name,
  :conformance_pack_arn,
  :conformance_pack_id,
  :delivery_s3_bucket,
  :delivery_s3_key_prefix,
  :conformance_pack_input_parameters,
  :last_update_requested_time,
  :created_by,
  :template_ssm_document_details)
  SENSITIVE = []
  include Aws::Structure
end