Class: Aws::ConfigService::Types::Connector
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::Connector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
The details of the connector, including the connector configuration and connector ARN.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
-
#connector_configuration ⇒ Types::ConnectorConfiguration
The provider-specific configuration for connecting to the third-party cloud service provider.
-
#created_time ⇒ Time
The date and time that the connector was created.
-
#name ⇒ String
The name of the connector.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
2376 2377 2378 2379 2380 2381 2382 2383 |
# File 'lib/aws-sdk-configservice/types.rb', line 2376 class Connector < Struct.new( :name, :arn, :connector_configuration, :created_time) SENSITIVE = [] include Aws::Structure end |
#connector_configuration ⇒ Types::ConnectorConfiguration
The provider-specific configuration for connecting to the third-party cloud service provider.
2376 2377 2378 2379 2380 2381 2382 2383 |
# File 'lib/aws-sdk-configservice/types.rb', line 2376 class Connector < Struct.new( :name, :arn, :connector_configuration, :created_time) SENSITIVE = [] include Aws::Structure end |