Class: Aws::ConfigService::Types::DescribeAggregateComplianceByConformancePacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeAggregateComplianceByConformancePacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_aggregator_name ⇒ String
The name of the configuration aggregator.
-
#filters ⇒ Types::AggregateConformancePackComplianceFilters
Filters the result by ‘AggregateConformancePackComplianceFilters` object.
-
#limit ⇒ Integer
The maximum number of conformance packs compliance details returned on each page.
-
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#configuration_aggregator_name ⇒ String
The name of the configuration aggregator.
2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-configservice/types.rb', line 2811 class DescribeAggregateComplianceByConformancePacksRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::AggregateConformancePackComplianceFilters
Filters the result by ‘AggregateConformancePackComplianceFilters` object.
2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-configservice/types.rb', line 2811 class DescribeAggregateComplianceByConformancePacksRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of conformance packs compliance details returned on each page. The default is maximum. If you specify 0, Config uses the default.
2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-configservice/types.rb', line 2811 class DescribeAggregateComplianceByConformancePacksRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-configservice/types.rb', line 2811 class DescribeAggregateComplianceByConformancePacksRequest < Struct.new( :configuration_aggregator_name, :filters, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |