Class: Aws::ConfigService::Types::DescribeConfigRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConfigRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_rule_names ⇒ Array<String>
The names of the Config rules for which you want details.
-
#filters ⇒ Types::DescribeConfigRulesFilters
Returns a list of Detective or Proactive Config rules.
-
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
Instance Attribute Details
#config_rule_names ⇒ Array<String>
The names of the Config rules for which you want details. If you do not specify any names, Config returns details for all your rules.
3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/aws-sdk-configservice/types.rb', line 3081 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::DescribeConfigRulesFilters
Returns a list of Detective or Proactive Config rules. By default, this API returns an unfiltered list. For more information on Detective or Proactive Config rules, see [ **Evaluation Mode** ][1] in the *Config Developer Guide*.
[1]: docs.aws.amazon.com/config/latest/developerguide/evaluate-config-rules.html
3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/aws-sdk-configservice/types.rb', line 3081 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned on a previous page that you use to get the next page of results in a paginated response.
3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/aws-sdk-configservice/types.rb', line 3081 class DescribeConfigRulesRequest < Struct.new( :config_rule_names, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |