Class: Aws::ConfigService::Types::DescribeConformancePacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DescribeConformancePacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conformance_pack_names ⇒ Array<String>
Comma-separated list of conformance pack names for which you want details.
-
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
-
#next_token ⇒ String
The ‘nextToken` string returned in a previous request that you use to request the next page of results in a paginated response.
Instance Attribute Details
#conformance_pack_names ⇒ Array<String>
Comma-separated list of conformance pack names for which you want details. If you do not specify any names, Config returns details for all your conformance packs.
3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-configservice/types.rb', line 3411 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of conformance packs returned on each page.
3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-configservice/types.rb', line 3411 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘nextToken` string returned in a previous request that you use to request the next page of results in a paginated response.
3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-configservice/types.rb', line 3411 class DescribeConformancePacksRequest < Struct.new( :conformance_pack_names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |