Class: Aws::ConfigService::Types::DisassociateResourceTypesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::DisassociateResourceTypesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_recorder ⇒ Types::ConfigurationRecorder
Records configuration changes to the resource types in scope.
Instance Attribute Details
#configuration_recorder ⇒ Types::ConfigurationRecorder
Records configuration changes to the resource types in scope.
For more information about the configuration recorder, see Working with the Configuration Recorder in the Config Developer Guide.
4100 4101 4102 4103 4104 |
# File 'lib/aws-sdk-configservice/types.rb', line 4100 class DisassociateResourceTypesResponse < Struct.new( :configuration_recorder) SENSITIVE = [] include Aws::Structure end |