Class: Aws::ConfigService::Types::EvaluationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::EvaluationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
The details of an Config evaluation. Provides the Amazon Web Services resource that was evaluated, the compliance of the resource, related time stamps, and supplementary information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation ⇒ String
Supplementary information about how the evaluation determined the compliance.
-
#compliance_type ⇒ String
Indicates whether the Amazon Web Services resource complies with the Config rule that evaluated it.
-
#config_rule_invoked_time ⇒ Time
The time when the Config rule evaluated the Amazon Web Services resource.
-
#evaluation_result_identifier ⇒ Types::EvaluationResultIdentifier
Uniquely identifies the evaluation result.
-
#result_recorded_time ⇒ Time
The time when Config recorded the evaluation result.
-
#result_token ⇒ String
An encrypted token that associates an evaluation with an Config rule.
Instance Attribute Details
#annotation ⇒ String
Supplementary information about how the evaluation determined the compliance.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |
#compliance_type ⇒ String
Indicates whether the Amazon Web Services resource complies with the Config rule that evaluated it.
For the ‘EvaluationResult` data type, Config supports only the `COMPLIANT`, `NON_COMPLIANT`, and `NOT_APPLICABLE` values. Config does not support the `INSUFFICIENT_DATA` value for the `EvaluationResult` data type.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |
#config_rule_invoked_time ⇒ Time
The time when the Config rule evaluated the Amazon Web Services resource.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |
#evaluation_result_identifier ⇒ Types::EvaluationResultIdentifier
Uniquely identifies the evaluation result.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |
#result_recorded_time ⇒ Time
The time when Config recorded the evaluation result.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |
#result_token ⇒ String
An encrypted token that associates an evaluation with an Config rule. The token identifies the rule, the Amazon Web Services resource being evaluated, and the event that triggered the evaluation.
4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/aws-sdk-configservice/types.rb', line 4040 class EvaluationResult < Struct.new( :evaluation_result_identifier, :compliance_type, :result_recorded_time, :config_rule_invoked_time, :annotation, :result_token) SENSITIVE = [] include Aws::Structure end |