Class: Aws::ConfigService::Types::GetResourceConfigHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::GetResourceConfigHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
The input for the GetResourceConfigHistory action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#chronological_order ⇒ String
The chronological order for configuration items listed.
-
#earlier_time ⇒ Time
The chronologically earliest time in the time range for which the history requested.
-
#later_time ⇒ Time
The chronologically latest time in the time range for which the history requested.
-
#limit ⇒ Integer
The maximum number of configuration items returned on each page.
-
#next_token ⇒ String
The
nextTokenstring returned on a previous page that you use to get the next page of results in a paginated response. -
#resource_id ⇒ String
The ID of the resource (for example.,
sg-xxxxxx). -
#resource_type ⇒ String
The resource type.
Instance Attribute Details
#chronological_order ⇒ String
The chronological order for configuration items listed. By default, the results are listed in reverse chronological order.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#earlier_time ⇒ Time
The chronologically earliest time in the time range for which the history requested. If not specified, the action returns paginated results that contain configuration items that start when the first configuration item was recorded.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#later_time ⇒ Time
The chronologically latest time in the time range for which the history requested. If not specified, current time is taken.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of configuration items returned on each page. The default is 10. You cannot specify a number greater than 100. If you specify 0, Config uses the default.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken string returned on a previous page that you use to
get the next page of results in a paginated response.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource (for example., sg-xxxxxx).
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 |
# File 'lib/aws-sdk-configservice/types.rb', line 5340 class GetResourceConfigHistoryRequest < Struct.new( :resource_type, :resource_id, :later_time, :earlier_time, :chronological_order, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |