Class: Aws::ConfigService::Types::OrganizationConfigRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-configservice/types.rb

Overview

An organization Config rule that has information about Config rules that Config creates in member accounts.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#excluded_accountsArray<String>

A comma-separated list of accounts excluded from organization Config rule.

Returns:

  • (Array<String>)


6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_timeTime

The timestamp of the last update.

Returns:

  • (Time)


6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#organization_config_rule_arnString

Amazon Resource Name (ARN) of organization Config rule.

Returns:

  • (String)


6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#organization_config_rule_nameString

The name that you assign to organization Config rule.

Returns:

  • (String)


6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#organization_custom_policy_rule_metadataTypes::OrganizationCustomPolicyRuleMetadataNoPolicy

An object that specifies metadata for your organization’s Config Custom Policy rule. The metadata includes the runtime system in use, which accounts have debug logging enabled, and other custom rule metadata, such as resource type, resource ID of Amazon Web Services resource, and organization trigger types that initiate Config to evaluate Amazon Web Services resources against a rule.



6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#organization_custom_rule_metadataTypes::OrganizationCustomRuleMetadata

An ‘OrganizationCustomRuleMetadata` object.



6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#organization_managed_rule_metadataTypes::OrganizationManagedRuleMetadata

An ‘OrganizationManagedRuleMetadata` object.



6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-configservice/types.rb', line 6198

class OrganizationConfigRule < Struct.new(
  :organization_config_rule_name,
  :organization_config_rule_arn,
  :organization_managed_rule_metadata,
  :organization_custom_rule_metadata,
  :excluded_accounts,
  :last_update_time,
  :organization_custom_policy_rule_metadata)
  SENSITIVE = []
  include Aws::Structure
end