Class: Aws::ConfigService::Types::OrganizationManagedRuleMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::OrganizationManagedRuleMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
An object that specifies organization managed rule metadata such as resource type and ID of Amazon Web Services resource along with the rule identifier. It also provides the frequency with which you want Config to run evaluations for the rule if the trigger type is periodic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description that you provide for your organization Config rule.
-
#input_parameters ⇒ String
A string, in JSON format, that is passed to your organization Config rule Lambda function.
-
#maximum_execution_frequency ⇒ String
The maximum frequency with which Config runs evaluations for a rule.
-
#resource_id_scope ⇒ String
The ID of the Amazon Web Services resource that was evaluated.
-
#resource_types_scope ⇒ Array<String>
The type of the Amazon Web Services resource that was evaluated.
-
#rule_identifier ⇒ String
For organization config managed rules, a predefined identifier from a list.
-
#tag_key_scope ⇒ String
One part of a key-value pair that make up a tag.
-
#tag_value_scope ⇒ String
The optional part of a key-value pair that make up a tag.
Instance Attribute Details
#description ⇒ String
The description that you provide for your organization Config rule.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#input_parameters ⇒ String
A string, in JSON format, that is passed to your organization Config rule Lambda function.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#maximum_execution_frequency ⇒ String
The maximum frequency with which Config runs evaluations for a rule. This is for an Config managed rule that is triggered at a periodic frequency.
MaximumExecutionFrequency parameter.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#resource_id_scope ⇒ String
The ID of the Amazon Web Services resource that was evaluated.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#resource_types_scope ⇒ Array<String>
The type of the Amazon Web Services resource that was evaluated.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#rule_identifier ⇒ String
For organization config managed rules, a predefined identifier from
a list. For example, IAM_PASSWORD_POLICY is a managed rule. To
reference a managed rule, see Using Config managed rules.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#tag_key_scope ⇒ String
One part of a key-value pair that make up a tag. A key is a general label that acts like a category for more specific tag values.
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |
#tag_value_scope ⇒ String
The optional part of a key-value pair that make up a tag. A value acts as a descriptor within a tag category (key).
7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-configservice/types.rb', line 7103 class OrganizationManagedRuleMetadata < Struct.new( :description, :rule_identifier, :input_parameters, :maximum_execution_frequency, :resource_types_scope, :resource_id_scope, :tag_key_scope, :tag_value_scope) SENSITIVE = [] include Aws::Structure end |