Class: Aws::ConfigService::Types::PutConformancePackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::PutConformancePackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conformance_pack_input_parameters ⇒ Array<Types::ConformancePackInputParameter>
A list of ‘ConformancePackInputParameter` objects.
-
#conformance_pack_name ⇒ String
The unique name of the conformance pack you want to deploy.
-
#delivery_s3_bucket ⇒ String
The name of the Amazon S3 bucket where Config stores conformance pack templates.
-
#delivery_s3_key_prefix ⇒ String
The prefix for the Amazon S3 bucket.
-
#tags ⇒ Array<Types::Tag>
The tags for the conformance pack.
-
#template_body ⇒ String
A string that contains the full conformance pack template body.
-
#template_s3_uri ⇒ String
The location of the file containing the template body (‘s3://bucketname/prefix`).
-
#template_ssm_document_details ⇒ Types::TemplateSSMDocumentDetails
An object of type ‘TemplateSSMDocumentDetails`, which contains the name or the Amazon Resource Name (ARN) of the Amazon Web Services Systems Manager document (SSM document) and the version of the SSM document that is used to create a conformance pack.
Instance Attribute Details
#conformance_pack_input_parameters ⇒ Array<Types::ConformancePackInputParameter>
A list of ‘ConformancePackInputParameter` objects.
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#conformance_pack_name ⇒ String
The unique name of the conformance pack you want to deploy.
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_s3_bucket ⇒ String
The name of the Amazon S3 bucket where Config stores conformance pack templates.
<note markdown=“1”> This field is optional.
</note>
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_s3_key_prefix ⇒ String
The prefix for the Amazon S3 bucket.
<note markdown=“1”> This field is optional.
</note>
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags for the conformance pack. Each tag consists of a key and an optional value, both of which you define.
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
A string that contains the full conformance pack template body. The structure containing the template body has a minimum length of 1 byte and a maximum length of 51,200 bytes.
<note markdown=“1”> You can use a YAML template with two resource types: Config rule (‘AWS::Config::ConfigRule`) and remediation action (`AWS::Config::RemediationConfiguration`).
</note>
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#template_s3_uri ⇒ String
The location of the file containing the template body (‘s3://bucketname/prefix`). The uri must point to a conformance pack template (max size: 300 KB) that is located in an Amazon S3 bucket in the same Region as the conformance pack.
<note markdown=“1”> You must have access to read Amazon S3 bucket. In addition, in order to ensure a successful deployment, the template object must not be in an [archived storage class] if this parameter is passed.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/storage-class-intro.html
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |
#template_ssm_document_details ⇒ Types::TemplateSSMDocumentDetails
An object of type ‘TemplateSSMDocumentDetails`, which contains the name or the Amazon Resource Name (ARN) of the Amazon Web Services Systems Manager document (SSM document) and the version of the SSM document that is used to create a conformance pack.
7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-configservice/types.rb', line 7116 class PutConformancePackRequest < Struct.new( :conformance_pack_name, :template_s3_uri, :template_body, :delivery_s3_bucket, :delivery_s3_key_prefix, :conformance_pack_input_parameters, :template_ssm_document_details, :tags) SENSITIVE = [] include Aws::Structure end |