Class: Aws::ConfigService::Types::RemediationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::RemediationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
An object that represents the details about the remediation exception. The details include the rule name, an explanation of an exception, the time when the exception will be deleted, the resource ID, and resource type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_rule_name ⇒ String
The name of the Config rule.
-
#expiration_time ⇒ Time
The time when the remediation exception will be deleted.
-
#message ⇒ String
An explanation of an remediation exception.
-
#resource_id ⇒ String
The ID of the resource (for example., sg-xxxxxx).
-
#resource_type ⇒ String
The type of a resource.
Instance Attribute Details
#config_rule_name ⇒ String
The name of the Config rule.
8271 8272 8273 8274 8275 8276 8277 8278 8279 |
# File 'lib/aws-sdk-configservice/types.rb', line 8271 class RemediationException < Struct.new( :config_rule_name, :resource_type, :resource_id, :message, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The time when the remediation exception will be deleted.
8271 8272 8273 8274 8275 8276 8277 8278 8279 |
# File 'lib/aws-sdk-configservice/types.rb', line 8271 class RemediationException < Struct.new( :config_rule_name, :resource_type, :resource_id, :message, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
An explanation of an remediation exception.
8271 8272 8273 8274 8275 8276 8277 8278 8279 |
# File 'lib/aws-sdk-configservice/types.rb', line 8271 class RemediationException < Struct.new( :config_rule_name, :resource_type, :resource_id, :message, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource (for example., sg-xxxxxx).
8271 8272 8273 8274 8275 8276 8277 8278 8279 |
# File 'lib/aws-sdk-configservice/types.rb', line 8271 class RemediationException < Struct.new( :config_rule_name, :resource_type, :resource_id, :message, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of a resource.
8271 8272 8273 8274 8275 8276 8277 8278 8279 |
# File 'lib/aws-sdk-configservice/types.rb', line 8271 class RemediationException < Struct.new( :config_rule_name, :resource_type, :resource_id, :message, :expiration_time) SENSITIVE = [] include Aws::Structure end |