Class: Aws::ConfigService::Types::ScopeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConfigService::Types::ScopeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-configservice/types.rb
Overview
Specifies the scope of resources to record from a third-party cloud service provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_regions ⇒ Boolean
Specifies whether to record resources from all supported regions for the third-party cloud service provider.
-
#included_regions ⇒ Array<String>
The list of regions from the third-party cloud service provider to include when recording resources.
-
#scope_type ⇒ String
The type of scope for the third-party cloud resources.
-
#scope_values ⇒ Array<String>
The list of specific scope values for the third-party cloud resources.
Instance Attribute Details
#all_regions ⇒ Boolean
Specifies whether to record resources from all supported regions for the third-party cloud service provider.
9163 9164 9165 9166 9167 9168 9169 9170 |
# File 'lib/aws-sdk-configservice/types.rb', line 9163 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :all_regions, :included_regions) SENSITIVE = [] include Aws::Structure end |
#included_regions ⇒ Array<String>
The list of regions from the third-party cloud service provider to
include when recording resources. Used when allRegions is set to
false.
9163 9164 9165 9166 9167 9168 9169 9170 |
# File 'lib/aws-sdk-configservice/types.rb', line 9163 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :all_regions, :included_regions) SENSITIVE = [] include Aws::Structure end |
#scope_type ⇒ String
The type of scope for the third-party cloud resources. Valid values
include tenant and subscription.
9163 9164 9165 9166 9167 9168 9169 9170 |
# File 'lib/aws-sdk-configservice/types.rb', line 9163 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :all_regions, :included_regions) SENSITIVE = [] include Aws::Structure end |
#scope_values ⇒ Array<String>
The list of specific scope values for the third-party cloud resources. For example, a list of Azure subscriptions or management groups.
9163 9164 9165 9166 9167 9168 9169 9170 |
# File 'lib/aws-sdk-configservice/types.rb', line 9163 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :all_regions, :included_regions) SENSITIVE = [] include Aws::Structure end |