Method: Aws::ConfigService::Types::TemplateSSMDocumentDetails#document_name
- Defined in:
- lib/aws-sdk-configservice/types.rb
#document_name ⇒ String
The name or Amazon Resource Name (ARN) of the SSM document to use to create a conformance pack. If you use the document name, Config checks only your account and Amazon Web Services Region for the SSM document.
8854 8855 8856 8857 8858 8859 |
# File 'lib/aws-sdk-configservice/types.rb', line 8854 class TemplateSSMDocumentDetails < Struct.new( :document_name, :document_version) SENSITIVE = [] include Aws::Structure end |